pub struct PauseTimerCommand {
pub protocol: ProtocolArg,
}Expand description
Pause the timer.
This command allows you to send a request to the server in order to pause the timer.
Fields
protocol: ProtocolArgImplementations